#-*- coding: utf-8 -*-


import macoop.school
from macoop.school import Student, SpecialStudent
from macoop.school import *

def Test():
	'''
	st1 = school.Student('Albert','Einstein')
	print(st1)

	st2 = Student('Bill','Gates')
	print(st2)

	stp1 = SpecialStudent('T','E',"T")

	teacher1 = Teacher('Ada')
	print(teacher1)
	'''
	st1 = school.Student('Albert','Einstein')
	print(st1)

	st2 = Student('Bill','Gates')
	print(st2)

	stp1 = SpecialStudent('T','E',"T")

	teacher1 = Teacher('Ada')
	print(teacher1)

